[![Actions Status](https://github.com/qtoggle/qtoggleserver/workflows/Release/badge.svg)](https://github.com/qtoggle/qtoggleserver/actions)

**qToggleServer** is a fully fledged [qToggle](https://github.com/qtoggle/docs/wiki/The-qToggle-API-1.0) implementation written in Python.
